import React from "react";
/**
 * Capture click event outside of the given HTMLElement.
 *
 * @param ref   Reference to the element
 * @param fn    Callback called on ref outside click
 * @param opts  Options
 */
export declare type UseClickOutside = (ref: React.RefObject<Node>, fn: ClickOutsideFn, opts?: Partial<ClickOutsideOpts>) => void;
export declare type ClickOutsideFn = (evt: Event) => void;
export declare type ClickOutsideOpts = {
    /**
     * Highest parent where the listener will be attached to.
     *
     * @default document
     */
    root: React.RefObject<Node>;
    /**
     * Blacklisted elements that will not trigger any event.
     *
     * @default []
     */
    except: React.RefObject<Node>[];
    /**
     * Listener event type.
     *
     * @default "click"
     */
    listenerType: keyof DocumentEventMap;
    /**
     * Listener options.
     *
     * @default {passive: true}
     */
    listenerOpts: boolean | AddEventListenerOptions;
};
export declare const defaultOpts: ClickOutsideOpts;
