import { useCallback, useEffect, useRef } from "react";
import isNumber from "lodash/fp/isNumber";
import useToggle from "../toggle";
import { defaultOpts } from "./interval.types";
export var useInterval = function (fn, overrideOpts) {
    var callback = useCallback(fn, []);
    var opts = Object.assign(defaultOpts, isNumber(overrideOpts) ? { delay: overrideOpts } : overrideOpts);
    var timeout = useRef(null);
    var _a = useToggle(opts.autoStart), isIntervalOn = _a[0], toggleInterval = _a[1];
    useEffect(function () {
        function clearTimeoutSafe() {
            timeout.current && clearTimeout(timeout.current);
            timeout.current = null;
        }
        if (isIntervalOn) {
            timeout.current = setInterval(callback, opts.delay);
        }
        else {
            clearTimeoutSafe();
        }
        return function () {
            clearTimeoutSafe();
        };
    }, [callback, isIntervalOn, opts.delay]);
    return [isIntervalOn, toggleInterval];
};
export default useInterval;
