/**
 * A persistant useState, based on React"s `useState` and localForage.
 * Supported drivers: localStorage, WebSQL and IndexedDB.
 */
export declare type UseStoredState = <T>(name: string, opts?: T | Partial<StoredStateOpts<T>>) => [T, (val: T) => Promise<void>, boolean];
export declare type StoredStateOpts<T> = {
    /**
     * Default value.
     */
    defaultVal: T;
    /**
     * LocalForage driver.
     *
     * @default "LOCALSTORAGE"
     */
    driver: StoredStateDriver;
};
export declare type StoredStateDriver = "LOCALSTORAGE" | "WEBSQL" | "INDEXEDDB";
export declare const defaultDriver: StoredStateDriver;
