import { useCallback, useEffect, useRef, useState } from "react";
import { v4 as uuid } from "uuid";
import invokeMap from "lodash/fp/invokeMap";
import isNumber from "lodash/fp/isNumber";
import noop from "lodash/fp/noop";
import { defaultOpts } from "./timeout.types";
var useTimeout = function (fn, overrideOpts) {
    var callback = useCallback(fn, []);
    var opts = Object.assign(defaultOpts, isNumber(overrideOpts) ? { delay: overrideOpts } : overrideOpts);
    var _a = useState(false), ready = _a[0], setReady = _a[1];
    var timeouts = useRef(new Map());
    var wrapper = useRef(noop);
    var abort = useRef(noop);
    var terminate = useRef(noop);
    useEffect(function () {
        wrapper.current = function () {
            var params = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                params[_i] = arguments[_i];
            }
            if (opts.persist) {
                invokeMap("persist", params);
            }
            var id = uuid();
            var wrapper = function () {
                callback.apply(void 0, params);
                timeouts.current.delete(id);
            };
            abort.current = function () {
                timeouts.current.forEach(function (_a) {
                    var t = _a[0];
                    return t && clearTimeout(t);
                });
                timeouts.current.clear();
                abort.current = noop;
                terminate.current = noop;
            };
            terminate.current = function () {
                timeouts.current.forEach(function (_a) {
                    var t = _a[0], wrapper = _a[1];
                    if (t) {
                        clearTimeout(t);
                        terminate.current = noop;
                        abort.current = noop;
                        wrapper();
                    }
                });
                timeouts.current.clear();
                abort.current = noop;
                terminate.current = noop;
            };
            timeouts.current.set(id, [setTimeout(wrapper, opts.delay), wrapper]);
        };
        setReady(true);
    }, [ready, callback, opts.delay, opts.persist]);
    return Object.assign(wrapper.current, {
        abort: function () { return abort.current(); },
        terminate: function () { return terminate.current(); },
    });
};
export default useTimeout;
